@@ -5,11 +5,13 @@ from datetime import datetime
 
 
 class Token:
-    def __init__(self, client_id, client_secret, grant_token=None):
+    def __init__(self, client_id, client_secret, grant_token=None, refresh_token=None):
         self.client_id = client_id
         self.client_secret = client_secret
-        self.access_token = None
-        self.refresh_token = None
+        self.access = None
+        self.refresh = refresh_token
+        if refresh_token is not None:
+        	self.access = self._generate()
         if grant_token is not None:
             self.access, self.refresh = self._authorize(grant_token)
         
